/* ------------------------------------------------------------------------------------------







	下層ページ格納CSS



	UPDATE：2022.11.30







------------------------------------------------------------------------------------------ */











/*



---



---------------------------------------------------------------------------*/











/*



---



---------------------------------------------------------------------------*/











/*



---



---------------------------------------------------------------------------*/











/*



---



---------------------------------------------------------------------------*/



hr{



	display: block;



	border-width: 1px 0 0;



	border-color: #ddd;



}



.hr_dotted hr{



	border-style: dashed;



}











/*



---



---------------------------------------------------------------------------*/



.listlink_wrp{



	margin-top: 1.5em;



}



.listlink_wrp a{



	display: block;



	padding: 15px 15px 15px 26px;



	color: inherit;



	border-style: dashed;



	border-color: #ddd;



	border-width: 1px 0 0;



	position: relative;



	background-image: url(../images/arrow_6x10_keycolor_border_left.png);



	background-position: 10px 20px;



	background-repeat: no-repeat;



	-webkit-background-size: 6px 10px;



	background-size: 6px 10px;



}



.listlink_wrp a:last-child{



	border-bottom-width: 1px;



}



.listlink_wrp a:hover{



	background-color: rgba(9, 73, 174, 0.05);



}







.listlink_wrp a[href$=".pdf"]{



	padding-right: 52px;



}



.listlink_wrp a[href$=".pdf"]:after{



	content: '';



	width: 32px;



	height: 32px;



	position: absolute;



	top: 50%;



	right: 10px;



	-webkit-transform: translateY(-50%);



	transform: translateY(-50%);



	background-image: url(../images/Adobe_PDF_file_icon_32x32.png);



	background-repeat: no-repeat;



	-webkit-background-size: 32px auto;



	background-size: 32px auto;



}











/*



---page anchor



---------------------------------------------------------------------------*/











/*



---category.php



---------------------------------------------------------------------------*/











.noarticle{



	padding: 100px 15px;



	background-color: #f5f5f5;



	text-align: center;



}







.pager{



	margin-top: 2em;



}



.pager-arrows{



	float: left;



}



.pager-arrows svg{



	vertical-align: middle;



}



.pager-arrows a,



.pager-arrows span{



	width: 35px;



	height: 35px;



	padding: 0;



	background-color: #004d9d;



	background-image: url(../images/arrow_6x10_wht_border_left.png);



	background-repeat: no-repeat;



	background-position: center center;



	-webkit-background-size: 6px 10px;



	background-size: 6px 10px;



	display: inline-block;



	margin-right: 5px;



	text-align: center;



}



.pager-arrows span{



	opacity: 0.25;



}







.pager-arrows > :first-child{



	-webkit-transform: rotate(-180deg);



	transform: rotate(-180deg);



}











.pager-arrows a:hover{



	background-color: rgba(9, 73, 174, 1);



}







.pager select[name="sp_paginate_links"]{



	float: right;



	font-size: 1.5rem;



	width: 300px;



	box-sizing: border-box;



	margin: 0 auto;



	display: block !important;



	-webkit-appearance: none;



	-moz-appearance: none;



	padding:5px 36px 5px 10px;



	border:1px solid #ccc;



	border-radius:3px;



	cursor:pointer;



	font-family: "ヒラギノ角ゴ ProN W3", "Hiragino Kaku Gothic ProN", "メイリオ", Meiryo, "游ゴシック", YuGothic, sans-serif;



	background-image: url(../images/icon_select_open.png);



	background-repeat: no-repeat;



	background-position: right 10px center;



	background-size: 16px auto;



}



.pager select[name="sp_paginate_links"]::-ms-expand{



	display: none;



}











/*



---single.php



---------------------------------------------------------------------------*/







.singleArticle-catList{



	padding: 5px 10px 10px;



	clear: both;



	background-color: #efefef;



}



.singleArticle-catList a{



	display: inline-block;



	padding: 10px;



	background-color: #009bb3;



/*	border-radius: 3px;*/



	margin: 5px 5px 0 0;



	font-size: 1.4rem;



	line-height: 1;



	color: #fff;



	text-decoration: none;



	border-width: 1px;



	border-style: solid;



	border-color: #009bb3;



}



.singleArticle-catList a:hover{



	background-color: #fff;



	color: #009bb3;



}







.singleArticle-con{



}







.singleArticle-con table,



.singleArticle-con table th,



.singleArticle-con table td{



	width: auto !important;



	height: auto !important;



}







.singleArticle-h2{



	margin-bottom: 0;



}







.singleArticle-date{



/*	color: #888;*/



	line-height: 1;



	display: table;



	border-collapse: collapse;



	margin-top: 30px;



}



.singleArticle-date span{



	display: table-cell;



	vertical-align: middle;



	padding: 10px;



}



.singleArticle-date span:first-child{



	border-style: solid;



	border-color: #4d4d4d;



	border-width: 0 1px;



}







.singleArticle-btn{



/*



	padding-top: 2.5em;



	border-top: 1px solid #ddd;



*/



}







.sigle-pastPost-alert{



	padding: 15px;



	border: 1px solid #BF0000;



	background-color: #fff0f0;



	color: #BF0000;



	margin-bottom: 2em;



}











/*



---mw wp form



---------------------------------------------------------------------------*/



.mw_wp_form{



/*	margin: 30px 0;*/



}



.mw_wp_form > :first-child{



	margin-top: 0 !important;



}



.mw_wp_form > :last-child{



	margin-bottom: 0 !important;



}



.mw_wp_form strong{



	color: #2293B1;



}



.mw_wp_form table{



	width: 100%;



}



.mw_wp_form table th,



.mw_wp_form table td{



	vertical-align: middle;



}



.mw_wp_form table th{



	width: 280px;



}







.mw_wp_form table th[colspan="2"]{



	background-color: #2293B1;



	color: #fff;



	border-left-color: #2293B1;



	border-right-color: #2293B1;



}







.mw_wp_form input[type="text"],



.mw_wp_form input[type="tel"],



.mw_wp_form input[type="email"]{



	-webkit-appearance: none;



	-moz-appearance: none;



	appearance: none;



	padding:5px;



	border:1px solid #ccc;



	border-radius:3px;



	display:inline-block;



	box-sizing:border-box;



	max-width:100%;



	width: 100%;



}



.mw_wp_form select{



	-webkit-appearance: none;



	-moz-appearance: none;



	appearance: none;



	padding:5px 36px 5px 10px;



	border:1px solid #ccc;



	border-radius:3px;



	cursor:pointer;



	font-family: "ヒラギノ角ゴ ProN W3", "Hiragino Kaku Gothic ProN", "メイリオ", Meiryo, "游ゴシック", YuGothic, sans-serif;



	background-image: url(../images/icon_select_open.png);



	background-repeat: no-repeat;



	background-position: right 10px center;



	background-size: 16px auto;



	min-width:150px;



}



.mw_wp_form select::-ms-expand {



  display: none;



}







.mw_wp_form input[type="submit"],



.mw_wp_form input[type="button"]{



	-webkit-appearance: none;



	-moz-appearance: none;



	appearance: none;



	display: block;



	max-width: 320px;



	width: 100%;



	margin: 10px auto 0;



	padding: 15px 30px;



	text-align: center;



	color: #fff;



	border-width: 0;



	background-image: url(../images/arrow_right_wht_6x11.png);



	background-repeat: no-repeat;



	background-position: right 5px center;



	-webkit-background-size: 6px auto;



	background-size: 6px auto;



	background-color: #094AB1;



	transition: all .5s;



	border-radius: 5px;



}



.mw_wp_form input[type="submit"]:hover,



.mw_wp_form input[type="button"]:hover{



	background-color: #2980B4;



	color: #fff;



}







.mw_wp_form input[type="submit"].back{



	background-color: #f2f2f2;



	color:inherit;



	border:1px solid #ddd;



	padding:10px 15px;



	background-image: none;



}



.mw_wp_form input[type="submit"].back:hover{



	background-color: #fff;



}







.mw_wp_form .error{



	margin-top: 5px;



	width: auto;



}







.mw_wp_form input.zip,



.mw_wp_form input.tel{



	width:6em;



}



.mw_wp_form input.shorttxt{



	width:6em;



}



.mw_wp_form input.longtxt{



	width:100%;



}



.mw_wp_form textarea{



	-webkit-appearance: none;



	-moz-appearance: none;



	appearance: none;



	border:1px solid #ccc;



	border-radius:3px;



	padding:5px;



	box-sizing:border-box;



	display:block;



	width:100%;



	font-family: "ヒラギノ角ゴ ProN W3", "Hiragino Kaku Gothic ProN", "メイリオ", Meiryo, "游ゴシック", YuGothic, sans-serif;



}



.mw_wp_form label.error{



	display:block;



	background-color: #B43032;



	color:#fff;



	padding:5px 10px;



	margin-top:5px;



	border-radius:3px;



}



.mwform-checkbox-field input[type="checkbox"]{



	vertical-align:middle;



}



.mw_wp_form .horizontal-item + .horizontal-item {



    margin-left: 0;



}



.mw_wp_form .horizontal-item{



	margin-right:30px;



	display:inline-block;



	padding:5px 0;



}







.mw_wp_form #graduated-year{



	width: 5em;



}







.mw_wp_form_confirm .conf_non{



	display: none !important;



}







.mw_wp_form table .nameField{



	display: inline-block;



}



.mw_wp_form table td .nameField:first-child{



	margin-right: 1em;



}



.mw_wp_form table .nameField input{



	width: 10em;



}







.mw_wp_form input#event,



.mw_wp_form input#eventtime{



	display: block;



	padding: 0;



	border: none;



}











/*



---サイトマップ



---------------------------------------------------------------------------*/



.sitemap .sm_wrp{



	overflow: hidden;



}



.sitemap .menu_global li{



	margin: 0;



	padding: 0;



}



.sitemap .menu_global li:before{



	display: none;



}



.sitemap .menu_global a{



	display: block;



	color: inherit;



}



.sitemap .menu_global{



	margin: 0 -10px;



}



.sitemap .menu_global:after{



	content: '';



	display: table;



	clear: both;



}



.sitemap .menu_global > li{



	float: left;



	width: calc(99.99% / 3);



	padding: 0 10px;



}



.sitemap .menu_global > li:nth-of-type(n+4){



	padding-top: 1.5em;



}



.sitemap .menu_global > li:nth-of-type(3n+1){



	clear: both;



}



.sitemap .menu_global > li > a{



	background-color: rgba(41, 128, 180, 0.15);



	padding: 15px 36px 15px 15px;



	position: relative;



}



.sitemap .menu_global > li > a:hover{



	background-color: rgba(41, 128, 180, 1);



	color: #fff;



}



.sitemap .menu_global .sub-menu{



	padding-top: 0.5em;



	margin: 0;



}







.sitemap .menu_global .sub-menu > li{



}



.sitemap .menu_global .sub-menu > li > a{



	background-image: url(../images/icon_triangle_6x8_gray.png);



	-webkit-background-size: 6px 8px;



	background-size: 6px 8px;



	background-position: 10px 0.9em;



	background-repeat: no-repeat;



	padding: 0.5em 0 0.5em 26px;



}



.notouch .sitemap .menu_global .sub-menu > li > a:hover{



	background-position: 20px 0.9em;



	color: #2980B4;



}







.sitemap .menu_global > li.other{



	clear: both;



	float: none;



	width: auto;



}



.sitemap .menu_global > li.other > a{



	display: none;



}



.sitemap .menu_global > li.other .sub-menu{



	padding: 15px;



	background-color: #f5f5f5;



}



.sitemap .menu_global > li.other .sub-menu li{



	display: inline-block;



}



.sitemap .menu_global > li.other .sub-menu li:nth-of-type(n+2){



	margin-left: 1.5em;



}











/*



---準備中



---------------------------------------------------------------------------*/



.under_construction{



	text-align: center;



	padding: 100px 0;



	font-family: "游ゴシック", YuGothic, "ヒラギノ角ゴ ProN W3", "Hiragino Kaku Gothic ProN", "メイリオ", Meiryo, sans-serif;



	font-weight: bold;



	font-size: 2.4rem;



	background-color: #f5f5f5;



}











/*



---



---------------------------------------------------------------------------*/



.common__globalmenu__ul {



	max-width: 1000px;



	margin-left: auto;



	margin-right: auto;



}



.sub__global__wrapper {



	background-color: rgba(0, 77, 157, 0.8);



}



.common__globalmenu__ul > li {



	padding-bottom: 0;



}



.common__globalmenu__ul > li.menu-item-has-children > a:before {



	content: none;



}



.sub__header__wrapper {



	display: flex;



}



.sub__header__wrapper h1 {



	display: flex;



	align-items: center;



	padding: 20px 20px 20px 60px;



	border-bottom: 3px solid #004d9d;



	max-width: 1000px;



	margin-left: auto;



	margin-right: auto;



	min-height: 180px;



	background-image: url(../images/kazari-top-main-625x675.png);



	background-size: auto 90%;



	background-repeat: no-repeat;



	background-position: 0 center;



	font-size: 4rem;



	width: 100%;



}











/*



---



---------------------------------------------------------------------------*/



.contents_sub_flex {



	padding: 40px 20px 60px;



	display: flex;



	max-width: 1040px;



	margin-left: auto;



	margin-right: auto;



}



.contents_body {



	flex-grow: 1;



}



.sub__sidemenu__wrapper {



	padding-left: 40px;



	width: 360px;



	flex-shrink: 0;



}



.sub__sidemenu__item {



	display: flex;



}



.sub__sidemenu__wrapper a {



	display: flex;



	align-items: center;



	min-height: 60px;



	background-color: #e8e8e8;



	color: inherit;



	border-left: 8px solid #004d9d;



	padding: 5px 28px 5px 12px;



	background-image: url(../images/arrow-border-8x12-blue-next-.png);



	background-repeat: no-repeat;



	background-size: 8px auto;



	background-position: right 10px center;



	width: 100%;



}



.sub__sidemenu__item + .sub__sidemenu__item {



	margin-top: 10px;



}



.sub__sidemenu__wrapper a[aria-current="page"],



.sub__sidemenu__wrapper a.active {



	background-color: #004d9d;



	color: #fff;



	background-image: url(../images/arrow-border-8x12-white-next-.png);



}



















/*



---



---------------------------------------------------------------------------*/



section + section {



    padding-top: 50px;



}



section > :first-child{



	margin-top: 0 !important;



}



section > :last-child{



	margin-bottom: 0 !important;



}



h2{



	font-size: 2.8rem;



	margin-bottom: 40px;



	position: relative;



	padding: 30px 0px 30px 10px;



}



h2:before {



	content: "";



	position: absolute;



	background-color: #e9f0f9;



	left: 0;



	top: 0;



	height: 100%;



	width: 24px;



	z-index: -1;



	transform: skewY(30deg);



}



h3 {



	font-size: 2.4rem;



	margin-top: 30px;



	padding: 0px 0px 14px;



	position: relative;



	overflow: hidden;



}



h3:after {



	content: "";



	position: absolute;



	bottom: 0;



	height: 6px;



	left: 30px;



	right: 0px;



	background-color: #e9f0f9;



	z-index: -1;



	transform: skewX(-30deg);



	transform-origin: right bottom;



}



h4{



	font-size: 2.2rem;



	margin-top: 30px;



}



h5{



	font-size: 2.0rem;



	margin-top: 30px;



}



h6{



	font-size: 1.8rem;



	margin-top: 30px;



}







.editorWrapper h4 {



	border-left: 6px solid #004d9d;



	padding: 10px 0 10px 10px;



}



.editorWrapper h5 {



	padding: 5px;



	color: #004d9d;



	border: 1px solid;



}







.contents_body p {



	font-size: 1.4rem;



    margin-top: 30px;



}



.contents_body p + p{



/*    margin-top: 20px;*/



}







.contents_body ul,



.contents_body ol{



	margin: 30px 0 0;



}



.contents_body li{



	padding: 0 0 0 1.5em;



	position: relative;



	margin-top: 20px;



}



.contents_body li:first-child{



	margin-top: 0;



}



.contents_body ul > li:before{



	content:"\0030fb";



	position: absolute;



	left: 0;



	top: 0;



	color: transparent;



	background-image: url(../images/icon_ul_20x20.png);



	background-repeat: no-repeat;



	background-position: center center;



	-webkit-background-size: 25% auto;



	background-size: 25% auto;



}



.contents_body ul.caution{



	margin: 20px 0 0 2px;



}



.contents_body ul.caution > li{



	font-size: 0.85em;



	color: #666;



	margin-top: 1em;



}



.contents_body ul.caution > li:before{



	content:"\00203b";



	color: #666;



	background-image: none;



}



.contents_body ol{



	counter-reset:li;



}



.contents_body ol > li:before{



	counter-increment:li;



	content:counter(li) ".";



	position: absolute;



	top: 0;



	left: -1em;



	text-align: right;



	width: 2em;



	color: inherit;



	background-image: none;



}



.contents_body ol.katakana > li {



    padding-left: 2em;



}



.contents_body ol.katakana > li:before{



	content:counter(li, katakana) ".";



	left: 0;



	text-align: left;



}



.contents_body ol.kakko > li {



    padding-left: 2em;



}



.contents_body ol.kakko > li:before{



	content:"("counter(li)")";



	left: 0;



	text-align: left;



}



.contents_body ol.num_caution{



	margin: 20px 0 0 0.5em;



}



.contents_body ol.num_caution > li{



	font-size: 0.85em;



	color: #666;



	margin-top: 1em;



}



.contents_body ol.num_caution > li:before{



	content:"\00203b"counter(li);



	color: #4d4d4d;



}







.contents_body table{



	margin: 30px 0 0;



	background-color: #fff;



}



.contents_body th,



.contents_body td{



	padding: 10px;



	border: 1px solid #ddd;



	word-break: break-all;



}



.contents_body th > :first-child,



.contents_body td > :first-child{



	margin-top: 0 !important;



}



.contents_body th > :last-child,



.contents_body td > :last-child{



	margin-bottom: 0 !important;



}



.contents_body th{



	background-color: #004d9d;



	color: #fff;



}



.contents_body td{



}



.table_layout_fix{



	width: 100%;



	table-layout: fixed;



}











/*



---



---------------------------------------------------------------------------*/



.authForm {



    border: 1px solid #ddd;



    border-radius: 10px;



    padding: 40px;



    max-width: 600px;



    margin-left: auto;



    margin-right: auto;



}



.authForm__pass {



    position: relative;



    padding-left: 140px;



}



.authForm__pass + .authForm__pass {



	margin-top: 10px;



}



.authForm__pass span {



    position: absolute;



    left: 0;



    top: 50%;



    transform: translateY(-50%);



}



.authForm__pass input {



    display: block;



    width: 100%;



    padding: 10px;



    -webkit-appearance: none;



    border: 1px solid #ddd;



}



.authForm input[type="submit"] {



    display: block;



    margin-left: auto;



    margin-right: auto;



    max-width: 100%;



    width: 200px;



    -webkit-appearance: none;



    border: 1px solid #ddd;



    background-color: #eee;



}



.authForm__caution {



    max-width: 600px;



    margin-left: auto;



    margin-right: auto;



}



.authForm__caution ul.caution {



	margin-left: 0;



}











/*



---



---------------------------------------------------------------------------*/



.greeting__main__thumb {



	max-width: 40%;



	width: 200px;



	float: right;



	margin: 0 0px 20px 40px;



	padding-top: 5px;



}



.greeting__main__thumb span {



	display: block;



	padding: 5px 5px 0;



	font-size: 1.4rem;



	color: #666;



}











/*



---



---------------------------------------------------------------------------*/



.generalmeeting__link__item a {



	display: block;



	padding: 40px 20px;



	color: inherit;



	font-size: 2rem;



	position: relative;



}



.generalmeeting__link__item {



	border-width: 1px 0px;



	border-style: dashed;



	border-color: #ddd;



}



.generalmeeting__link__item + .generalmeeting__link__item {



	border-top-width: 0;



}



.generalmeeting__link__item a:after {



	content: "";



	border-style: solid;



	border-width: 0 1px 1px 0px;



	width: 50px;



	height: 12px;



	position: absolute;



	right: 10px;



	bottom: 10px;



	transform-origin: right bottom;



	transform: skewX(40deg);



	transition: all .5s;



}



.generalmeeting__link__item a:hover:after {



	transform: skewX(40deg) translateX(20px);



}



.generalmeeting__link__item a:hover {



	color: #004d9d;



}











/*



---



---------------------------------------------------------------------------*/



.generalmeeting__latest__wrapper + .generalmeeting__latest__wrapper {



	margin-top: 20px;



}



.generalmeeting__latest__year {



	font-size: 3rem;



	font-weight: bold;



	width: 160px;



}



.generalmeeting__latest__flex {



	flex-wrap: nowrap;



	padding: 20px 5px;



	border-style: solid;



	border-width: 1px 0;



	border-color: #ddd;



	align-items: flex-start;



	background-color: #fff;



}



.generalmeeting__latest__flex + .generalmeeting__latest__flex {



	border-top-width: 0;



}



.generalmeeting__latest__day {



	width: 90px;



	flex-shrink: 0;



}



.generalmeeting__latest__list {



}



.generalmeeting__latest__kai {



	flex-basis: 100%;



}



.generalmeeting__latest__place {



	flex-basis: 100%;



	padding-left: 20px;



}







.generalmeeting__past__wrapper {



	background-color: #f7f7f9;



}



.generalmeeting__past__wrapper + .generalmeeting__past__wrapper {



	margin-top: 10px;



}



.generalmeeting__past__button {



	display: block;



	padding: 20px 40px 20px 20px;



	font-size: 2rem;



	color: inherit;



	font-weight: bold;



	position: relative;



}



.generalmeeting__past__button:before {



	content: "";



	position: absolute;



	width: 8px;



	height: 8px;



	border-style: solid;



	border-width: 0 1px 1px 0;



	right: 20px;



	top: 50%;



	transform: translateY(-50%) rotate(45deg);



	transition: all .5s;



}



.generalmeeting__past__button.open:before {



	transform: translateY(-50%) rotate(-135deg);



}



.generalmeeting__past__contents {



	padding: 0px 20px 20px;



}



.generalmeeting__past__wrapper .generalmeeting__latest__year {



	font-size: 1.6rem;



}



.generalmeeting__past__linklist a {



	display: block;



	color: inherit;



	background-color: #fff;



	padding: 20px 10px;



	background-image: url(../images/arrow-border-8x12-blue-next-.png);



	background-repeat: no-repeat;



	background-position: right 10px center;



	background-size: 8px auto;



	line-height: 1.5;



}



.generalmeeting__past__linklist a:hover {



	background-position: right 0px center;



	color: #004d9d;



}



.generalmeeting__past__linklist p + p {



	margin-top: 4px;



}







[href].generalmeeting__past__linkbtn__inner:hover {



	color: #004d9d;



	background-position: right 0px center;



}



[href].generalmeeting__past__linkbtn__inner {



	padding: 10px 28px 10px 10px;



	background-image: url(../images/arrow-border-8x12-blue-next-.png);



	background-repeat: no-repeat;



	background-size: 8px auto;



	background-position: right 10px center;



}



.generalmeeting__past__linkbtn__inner {



	background-color: #fff;



	color: inherit;



	display: flex;



	height: 100%;



	align-items: center;



	padding: 10px;



}



.generalmeeting__past__linkbtn__item {



	padding: 4px 2px 0;



}



.generalmeeting__past__linkbtn__flex {



	margin: -4px -2px 0;



}







.generalmeeting__latest__list table {



	width: 100%;



	table-layout: fixed;



	margin-top: 0px;



}



.generalmeeting__latest__list td {



	border-width: 1px 0;



}



.generalmeeting__latest__list td:nth-of-type(1) {



	width: 90px;



}











/*



---



---------------------------------------------------------------------------*/



.shisetsu__shisetsu__flex {



	color: inherit;



	padding: 20px 10px;



	border-style: dashed;



	border-color: #ddd;



	border-width: 1px 0;



	position: relative;



	align-items: center;



	overflow: hidden;



}



.shisetsu__shisetsu__flex + .shisetsu__shisetsu__flex {



	border-top-width: 0px;



}



a.shisetsu__shisetsu__flex:hover:before {



	transform: skewX(40deg) scaleX(5);



}



.shisetsu__shisetsu__flex:before {



	content: "";



	position: absolute;



	width: 30%;



	top: 0px;



	bottom: 0px;



	left: 0px;



	background-color: #f7f7f9;



	z-index: -1;



	transform-origin: left bottom;



	transform: skewX(30deg);



	transition: all .5s;



}



a.shisetsu__shisetsu__flex:hover:after {



	transform: skewX(40deg) translateX(10px);



	



}



a.shisetsu__shisetsu__flex:after {



	content: "";



	border-style: solid;



	border-width: 0 1px 1px 0px;



	width: 50px;



	height: 12px;



	position: absolute;



	right: 10px;



	bottom: 10px;



	transform-origin: right bottom;



	transform: skewX(40deg);



	transition: all .5s;



}



.shisetsu__shisetsu__thumb {



	max-width: 150px;



	flex-shrink: 0;



	position: relative;



}



.shisetsu__shisetsu__text {



	padding-left: 20px;



}











/*



---



---------------------------------------------------------------------------*/



.movie__movie__inner {



	display: block;



	height: 100%;



	color: inherit;



	position: relative;



}



.movie__movie__thumb {



	overflow: hidden;



	position: relative;



}



.movie__movie__thumb:before {



	content: "";



	display: block;



	padding-bottom: 56.25%;



	background-color: #000;



}



.movie__movie__thumb:after {



	content: "";



	position: absolute;



	top: 0;



	left: 0;



	right: 0;



	bottom: 0;



	background-image: url(../images/icon-youtube-176x124-color.png);



	background-repeat: no-repeat;



	background-size: 56px;



	background-position: center;



	transition: all .5s;



}



.movie__movie__thumb img {



	position: absolute;



	width: 100%;



	top: 50%;



	left: 0;



	transform: translateY(-50%);



	opacity: .5;



	transition: all .5s;



}



a:hover .movie__movie__thumb:after {



	transform: scale(1.2);



}



a:hover .movie__movie__thumb img {



	opacity: 1;



}



.movie__movie__title {



	padding: 20px 10px 0px;



	position: relative;



	font-size: 1.8rem;



}



.movie__movie__title:before {



	content: "";



	position: absolute;



	width: 100px;



	height: 12px;



	background-color: #d3e8fd;



	bottom: 0;



	left: 10px;



	z-index: -1;



}











/*



---



---------------------------------------------------------------------------*/



.qa__main__box {



	border-style: solid;



	border-color: #ddd;



	border-width: 1px 0;



	overflow: hidden;



}



.qa__main__box + .qa__main__box {



	border-top-width: 0;



}



.qa__main__q {



	padding: 20px 30px 20px 10px;



	font-weight: bold;



	color: inherit;



	position: relative;



	display: block;



}



.qa__main__q.open {



	color: #004d9d;



}



.qa__main__q:before {



	content: "Q";



	position: absolute;



	color: #004d9d;



	opacity: .1;



	font-size: 6rem;



	line-height: 1;



	top: 0;



	left: 0;



}



.qa__main__q:after {



	content: "";



	width: 8px;



	height: 12px;



	position: absolute;



	right: 10px;



	top: 50%;



	background-image: url(../images/arrow-border-8x12-blue-next-.png);



	background-size: 100% auto;



	background-repeat: no-repeat;



	transform: rotate(90deg) translateX(-50%);



	transition: all .5s;



}



.qa__main__q.open:after {



	transform: rotate(-90deg) translateX(50%);



}



.qa__main__a {



	display: none;



	padding: 20px 10px 40px 40px;



	position: relative;



}



.qa__main__a:before {



	content: "";



	width: 4px;



	top: 0;



	bottom: 20px;



	left: 18px;



	background-color: #004d9d;



	position: absolute;



}











/*



---



---------------------------------------------------------------------------*/



.inquiery__main__text {



	position: relative;



	padding: 30px 40px 40px 50px;



}



.inquiery__main__text:before {



	content: "";



	position: absolute;



	z-index: -1;



	border: 1px solid #004d9d;



	top: -28px;



	bottom: 0;



	left: 10px;



	right: 0;



}



.inquiery__main__wrapper h3 {



	padding: 0px 20px 0px 0px;



}



.inquiery__main__wrapper h3:before, .inquiery__main__wrapper h3:after {



	content: none;



}



.inquiery__main__wrapper h3 span {



	display: inline-block;



	background-color: #fff;



	padding: 0 20px 10px 0;



}











/*



---



---------------------------------------------------------------------------*/



.sitemap__menu__ul .sitemaponly {



	display: block;



}



.sitemap__menu__ul li:before {



	content: none !important;



}



.sitemap__menu__ul a {



	display: block;



	color: inherit;



}



.sitemap__menu__ul a:hover {



	color: #004d9d;



}



.sitemap__menu__ul > li {



	width: 50%;



	padding: 40px 20px;



	border-style: dashed;



	border-color: #ddd;



	border-top-width: 1px;



	margin: 0;



}



.sitemap__menu__ul > li:nth-of-type(odd) {



	border-right-width: 1px;



}



.sitemap__menu__ul > li > a {



	display: none;



}



.sitemap__menu__ul > li > .sub-menu {



	margin: 0;



}



.sitemap__menu__ul > li > .sub-menu > li {



	padding: 0;



	margin: 0;



	line-height: 2.0em;



}



.sitemap__menu__ul > li > .sub-menu > li > .sub-menu {



	margin-top: 25px;



}



.sitemap__menu__ul > li > .sub-menu > li > .sub-menu > li > a {



	font-size: 1.4rem;



}







.sitemap__top__wrapper a {



	display: inline-block;



	background-color: #004d9d;



	padding: 10px 20px;



	color: #fff;



	border-radius: 5px;



	border: 1px solid #004d9d;



}



.sitemap__top__wrapper a:hover {



	background-color: transparent;



	color: #004d9d;



}











/*



---



---------------------------------------------------------------------------*/



.organization__shibu__box + .organization__shibu__box {



	margin-top: 40px;



}



.organization__shibu__box table {



	width: 100%;



	table-layout: fixed;



	margin-top: 5px;



}



.organization__shibu__box th {



	text-align: center;



}



.organization__shibu__box td:nth-of-type(1) {



	background-color: #f3f8ff;



	color: #004d9d;



}



.organization__shibu__box td:nth-of-type(3) {



	text-align: right;



}



.organization__shibu__shibu a:hover {



	background-color: #009bb3;



}



.organization__shibu__kuiki {



	display: inline-block;



	background-color: #004d9d;



	font-size: 1.3rem;



	color: #fff;



	border-radius: 3px;



	padding: 1px 8px 0;



	vertical-align: text-bottom;



}



.organization__remodal__wrapper {



	background-color: transparent;



}



.organization__remodal__contents {



	background-color: #fff;



	padding: 40px;



	border-radius: 3px;



}



.organization__dosokai__box table {



	width: 100%;



	table-layout: fixed;



}



.organization__dosokai__box th:nth-of-type(1) {



	width: 70%;



}



.organization__dosokai__box th {



	text-align: center;



}











/*



---



---------------------------------------------------------------------------*/



.common__pageanchor__wrapper {



	padding-bottom: 40px;



}



.common__pageanchor__inner {



	display: block;



	font-size: 1.4rem;



	color: inherit;



	padding: 0 18px 0 5px;



	position: relative;



}



.common__pageanchor__inner:before {



	content: "";



	height: 10px;



	width: 100%;



	position: absolute;



	background-color: #e9f4ff;



	z-index: -1;



	bottom: 0;



	left: 0;



}



.common__pageanchor__inner:after {



	width: 4px;



	height: 6px;



	content: "";



	position: absolute;



	background-image: url(../images/arrow-border-8x12-blue-next-.png);



	background-size: 4px auto;



	background-repeat: no-repeat;



	right: 5px;



	top: 50%;



	transform: rotate(90deg) translateX(-50%);



}











/*



---



---------------------------------------------------------------------------*/



.news__article__inner:nth-of-type(1) {



	border-top-width: 1px;



}



.news__article__inner {



	display: flex;



	align-items: center;



	padding: 20px 10px;



	border-style: dashed;



	border-color: #ddd;



	border-width: 0 0 1px;



	color: inherit;



	position: relative;



	overflow: hidden;



}



.news__article__inner:after {



	content: "";



	border-style: solid;



	border-width: 0 1px 1px 0px;



	width: 50px;



	height: 12px;



	position: absolute;



	right: 10px;



	bottom: 10px;



	transform-origin: right bottom;



	transform: skewX(40deg);



	transition: all .5s;



}



.news__article__inner:before {



	content: "";



	position: absolute;



	width: 40%;



	top: 0px;



	bottom: 0px;



	left: 0px;



	background-color: #f7f7f9;



	z-index: -1;



	transform-origin: left bottom;



	transform: skewX(30deg);



	transition: all .5s;



}



.news__article__inner:hover:before {



	transform: skewX(40deg) scaleX(3.5);



}



.news__article__thumb {



	width: 30%;



	flex-shrink: 0;



	background-size: cover;



	background-position: center;



	position: relative;



	align-self: flex-start;



}



.news__article__thumb:before {



	content: "";



	display: block;



	padding-bottom: 56.25%;



}



.news__article__thumb span {



	position: absolute;



	font-size: 1rem;



	background-color: #444;



	bottom: 0;



	right: 0;



	color: #fff;



	padding: 2px 10px;



}



.news__article__text {



	padding-left: 20px;



}



.news__article__date {



	color: #888;



	font-size: 1.4rem;



}











/*



---



---------------------------------------------------------------------------*/



.delegate__main__block + .delegate__main__block {



	margin-top: 40px;



}



.delegate__main__block table {



	table-layout: fixed;



	margin-top: 5px;



	width: 100%;



}



.delegate__main__block .col3 {



	width: 40px;



}



.delegate__main__block .col4 {



	width: 80px;



}



.delegate__main__block .col5 {



	width: 80px;



}



.delegate__main__block td:nth-of-type(1) {



	background-color: #f3f8ff;



	color: #004d9d;



}



.delegate__main__block td:nth-of-type(3),



.delegate__main__block td:nth-of-type(4),



.delegate__main__block td:nth-of-type(5) {



	text-align: center;



	padding-left: 2px;



	padding-right: 2px;



}



.delegate__main__block th,



.delegate__main__block td {



	padding: 5px;



	vertical-align: middle;



}











/*



---



---------------------------------------------------------------------------*/



.net__login__wrapper {



	padding-top: 40px;



	border-top: 1px dashed #ddd;



}



.net__loginbtn__inner {



	height: 100%;



}







.net__info__wrapper {



	position: relative;



	background-color: #fafafa;



}



.net__info__inner {



	position: relative;



	padding: 40px;



}



.net__info__wrapper:before,



.net__info__wrapper:after,



.net__info__inner:before,



.net__info__inner:after {



	content: "";



	position: absolute;



	width: 40px;



	height: 40px;



	border-color: #ddd;



	border-style: solid;



	border-width: 6px;



}



.net__info__wrapper:before {



	top: 0;



	left: 0;



	border-right-width: 0px !important;



	border-bottom-width: 0px !important;



}



.net__info__wrapper:after {



	border-bottom-width: 0px !important;



	border-left-width: 0px !important;



	top: 0;



	right: 0;



}



.net__info__inner:before {



	border-right-width: 0 !important;



	border-top-width: 0 !important;



	bottom: 0;



	left: 0;



}



.net__info__inner:after {



	border-left-width: 0 !important;



	border-top-width: 0 !important;



	right: 0;



	bottom: 0;



}











/*



---



---------------------------------------------------------------------------*/



.memberlist__link__title {



	padding: 10px;



	background-color: #004d9d;



	color: #fff;



}



.memberlist__link__flex {



	flex-wrap: nowrap;



	color: inherit;



	border: 1px solid #ddd;



}



.memberlist__link__name:hover {



	color: #fff;



	background-color: #004d9d;



}



.memberlist__link__name {



	background-color: #e9f0f9;



	color: #004d9d;



	padding: 10px;



	width: 200px;



	flex-shrink: 0;



	display: block;



}



.memberlist__link__contents {



	padding: 10px;



	position: relative;



	overflow: hidden;



	flex-grow: 1;



}



.memberlist__link__contents:after {



	content: "";



	top: 0;



	bottom: 0;



	right: 0;



	width: 28px;



	position: absolute;



	background-color: #e9f0f9;



	background-image: url(../images/arrow-border-8x12-blue-next-.png);



	background-repeat: no-repeat;



	background-size: 8px auto;



	background-position: center;



	transform: translateX(100%);



	transition: all .5s;



}



a:hover .memberlist__link__contents:after {



	transform: translateX(0);



}



.memberlist__link__name span {



	display: block;



	font-size: 1.4rem;



	margin-top: 4px;



}



.memberlist__link__flex + .memberlist__link__flex {



	border-top-width: 0px;



}











/*



---



---------------------------------------------------------------------------*/



.regulations__main__flex + .regulations__main__flex {



	margin-top: 40px;



}



.regulations__main__flex {



	flex-wrap: nowrap;



}



.regulations__main__left {



	width: 80px;



	flex-shrink: 0;



	font-weight: bold;



}



.regulations__main__right p,



.regulations__main__right ul,



.regulations__main__right ol,



.regulations__main__right table {



	margin-top: 20px;



}







.regulations__kaitei__table table {



	margin-left: auto;



	font-size: 1.2rem;



}



.regulations__kaitei__table th, .regulations__kaitei__table td {



	padding: 10px 0 0 10px;



	text-align: right;



	border-width: 0;



}



.regulations__kaitei__table tr:nth-of-type(1) th, .regulations__kaitei__table tr:nth-of-type(1) td {



	padding-top: 0px;



}











/*



---



---------------------------------------------------------------------------*/



.ao__entry__flex {



	flex-wrap: nowrap;



}



.ao__entry__left {



	flex-grow: 1;



	padding-right: 20px;



}



.ao__entry__right {



	max-width: 40%;



	flex-shrink: 0;



}











/*



--- 飲食店/宿泊施設NAVI(2022.4.19設置)



---------------------------------------------------------------------------*/







.ae-navi-flame {



	-js-display: flex;



	display: flex;



}



	.ae-navi-flame .right {



		/*align-self: center;*/



	}



		.ae-navi-flame .right .bg-image {



			margin-top: -160px;



		}



	.ae-navi-flame .left {



		min-width: 400px;



		padding-right: 40px;



		max-width: 440px;



	}







.ae-navi-flame-b {



	-js-display: flex;



	display: flex;



}



	.ae-navi-flame-b .right {



		padding-left: 20px;



	}



	.ae-navi-flame-b .left {



		max-width: 610px;



		padding-right: 20px;



		width: 100%;



	}











.inner-flame {



	-js-display: flex;



	display: flex;



}



.inner-flame.side {



	flex-direction: column;



}



	.inner-flame .right {



		padding-left: 10px;



	}



		.inner-flame .right > h3 {



			font-size: 1.8rem;



			margin: 40px 0 10px 0;



			padding: 0 0 10px;



		}



		.inner-flame .right > h3:after {



			content: "";



			position: absolute;



			bottom: 0;



			height: 1px;



			left: 0px;



			right: 0px;



			background-color: rgb(0,77,157);



			z-index: -1;



			transform: none;



			transform-origin: unset;



		}



		.inner-flame .right .inner {



			padding-top: 15px;



		}



			.inner-flame .right .inner > h3 {



				margin: 0 0 10px 0;



				padding: 0;



			}



			.inner-flame .right .inner > h3 :before{



				content: "";



				position: absolute;



				top: 50%;



				left: 0;



				-webkit-transform: translateY(-40%);



				transform: translateY(-40%);



				border: 5px solid transparent;



				border-top: 8px solid rgb(77,77,77);  



			}



			.inner-flame .right .inner > h3:after {



				content: "";



				position: static;



				background: none;



			}



				.inner-flame .right .inner > h3 > span {



					padding-left: 15px;



				}



	.inner-flame .left {



		padding-right: 10px;



	}











.aen-search-flame {



	position: relative;



	width: 100%;



}



	.aen-search-flame > h3 {



		font-size: 2.2rem;



	}



	.aen-search-flame.side > h3 {



		border-left: 8px solid #004d9d;



		font-size: 1.6rem;



		padding: 10px 0 10px;



	}



	.aen-search-flame.side > h3::after {



		content: none;



	}



	.aen-search-flame .inner {



		padding-top: 30px;



		width: 100%;



	}



		.aen-search-flame .inner h3 {



			font-size: 1.8rem;



			margin: 10px 0;



			padding: 0 0 10px;



		}



		.aen-search-flame .inner h3 {



			font-size: 1.8rem;



			margin: 10px 0;



			padding: 0 0 10px;



		}



		.aen-search-flame .inner h3:after {



			content: "";



			position: absolute;



			bottom: 0;



			height: 1px;



			left: 0px;



			right: 0px;



			background-color: rgb(0,77,157);



			z-index: -1;



			transform: none;



			transform-origin: unset;



		}



			.aen-search-flame .inner h3 > span {



				padding-left: 10px;



			}







		.aen-search-flame input[type=checkbox] {



			display: none; /* チェックボックスを非表示にする */



		}



		.aen-search-flame input[type=checkbox]+label {



			display: inline-block;



			background-color: rgba(230,230,230,1);



			border: 1px solid rgb(153,153,153);



			border-radius: 3px;



			cursor: pointer;



			color: rgb(77,77,77);



			font-size: 1.2rem;



			height: 30px;



			margin: 5px;



			max-width: 120px;



			padding: 5px;



			position: relative;



			text-align: center;



			width: auto;



		}



		.aen-search-flame input[type=checkbox]:checked+label {



			background-color: rgba(219,221,255,1);



			border: 1px solid rgb(46,49,146);



		}



			.aen-search-flame input[type=checkbox]+label > span {



				/*display: block;



				position: absolute;



				top: 50%;



				left: 50%;



				-webkit-transform: translate(-50%, -50%);



				transform: translate(-50%, -50%);*/



				white-space: nowrap;



				width: 100%;



			}







.eat-list-flame {



	-js-display: flex;



	display: flex;



	box-shadow: 0px 0px 4px 2px rgba(230,230,230,1);



	margin-bottom: 20px;



	padding: 10px;



}



	.eat-list-flame .left {



		max-width: 200px;



	}



		.eat-list-flame .left figure {



			min-width: 200px;



		}



			.eat-list-flame .left figure > img {



				/*width:200px;*/



				height:200px;



				object-fit:cover;



			}



	.eat-list-flame .right {



		padding-left: 15px;



		position: relative;



		width: 100%;



	}



	.eat-list-flame .right .new {



		font-size: 1.6rem;



		font-weight: 700;



		/* font-style: italic; */



		font-family: "Noto Serif JP", "Times New Roman", "游明朝", YuMincho,"ヒラギノ明朝 Pr6 W6","Hiragino Mincho Pro", "HGS明朝E","メイリオ", "ＭＳ Ｐ明朝","MS PMincho",Meiryo, serif;



		background-color: crimson;



		color: white;



		padding: 2px 8px;



		position: absolute;



		right: 5px;



		bottom: 4px;



	}



	.eat-list-flame h3 {



		font-size: 2.2rem;



		margin-top: 10px;



		padding: 0;



	}



	.eat-list-flame h3::after {



		content: none;



	}



	.eat-list-flame a {



		color: rgb(51,51,51);



	}



	.eat-list-flame .eat-acc {



		font-size: 1.2rem;



	}



	.eat-list-flame .eat-ete {



		padding-top: 15px;



	}



	.eat-list-flame .eat-cat {



		display: inline-block;



		border: 1px solid rgb(204,204,204);



		border-radius: 10px;



		font-size: 1.2rem;



		margin: 5px 3px;



		padding: 3px 8px;



	}







/* single */



.pageslider__wrapper {



	max-width: 550px;



	margin: 0 auto 20px auto;



	position: relative;



	width: 100%;



	/*z-index: 1;*/



}



/*.pageslider__wrapper:before {



	content: "";



	position: absolute;



	top: 0;



	bottom: 0;



	width: 100%;



	max-width: 625px;



}*/



.pageslider__slick {



	max-width: 550px;



	margin: 0 auto;



	/*padding-top: 66.67%!important;*/



	padding: 0 50px;



	z-index: -1;



}



	.pageslider__slick .slick-prev,



	.pageslider__slick .slick-next {



		height: 100px;



		width: 50px;



	}



	.slick-initialized .slick-slide {



		z-index: -100000!important;



	}







.pageslider__slick__item {



	overflow: hidden;



	/*max-height: 700px;*/



	background-size: cover;



	background-position: center;



	padding-top: 66.67%;



	position: relative;



	z-index: -1;



}



	.pageslider__slick__item > span {



		position: absolute;



		bottom: 0;



		display: block;



		color: rgb(255,255,255);



		font-size: 1.8rem;



		padding: 10px;



		background-color: rgba(0,0,0,1);



		opacity: .5;



		width: 100%;



		z-index: 1;



	}



/*.pageslider__slick__item:before {



	content: "";



	display: block;



	padding-bottom: 20%;



	background-color: rgba(0,0,0,.8);



	opacity: .3;



}*/



.pageslider__copy {



	position: absolute;



	width: 100%;



	padding: 20px;



	font-size: 4.5vw;



	color: #fff;



	text-align: center;



	top: 50%;



	left: 0;



	transform: translateY(-50%);



	line-height: 1.2;



}











.eat-post-flame {



	



}



	.eat-post-flame .eat-cat {



		display: inline-block;



		border: 1px solid rgb(204,204,204);



		border-radius: 10px;



		font-size: 1.2rem;



		margin: 5px 3px;



		padding: 3px 8px;



	}











.con-block {}



	.con-block > h3::after {



		content: none;



	}



	.con-block .block-si {



		margin-bottom: 30px;



	}



	.con-block .block-si {



		margin-bottom: 30px;



	}



	.con-block .block-sf {



		-js-display: flex;



		display: flex;



		background-size: auto auto;



		background-color: rgba(255, 255, 255, 1);



		background-image: repeating-linear-gradient(-45deg, transparent, transparent 2px, rgba(233, 240, 249, 1) 2px, rgba(233, 240, 249, 1) 7px );



		font-size: 1.4rem;



		margin-bottom: 30px;



		padding: 10px;



	}



		.con-block .block-sf div:nth-of-type(1) {



			min-width: 140px;



			padding: 10px;



		}



		.con-block .block-sf div:nth-of-type(2) {



			background-color: rgba(255,255,255,1);



			padding: 10px;



			width: 100%;



		}



	.con-block .block-shop {



		-js-display: flex;



		display: flex;



		background-color: rgba(242, 242, 242, 1);



		font-size: 1.4rem;



		padding: 5px 10px;



	}



		.con-block .block-shop div:nth-of-type(1) {



			min-width: 140px;



			padding: 10px;



		}



		.con-block .block-shop div:nth-of-type(2) {



			background-color: rgba(255,255,255,1);



			padding: 10px;



			width: 100%;



		}



	.con-block .block-message {



		-js-display: flex;



		display: flex;



		flex-wrap: wrap;



		background-color: rgba(242, 242, 242, 1);



		font-size: 1.4rem;



		padding: 20px;



	}



		.con-block .block-message figure {



			min-width: 90px;



		}



			.con-block .block-message figure > img {



				/*width:200px;*/



				height:90px;



				object-fit:cover;



			}



		.con-block .block-message div:nth-of-type(1) {



			min-width: 90px;



		}



		.con-block .block-message div:nth-of-type(2) {



			padding: 10px;



			/*width: 100%;*/



		}



		.con-block .block-message div:nth-of-type(3) {



			margin-left:100px;



		}











/**/



.aen-button {



	-js-display: flex;



	display: flex;



}



	.aen-button > button {



		align-items: center;



		background-color: rgba(255,255,255,1);



		padding: 5px 28px 5px 12px;



		background-image: url(../images/arrow-border-8x12-blue-next-.png);



		background-repeat: no-repeat;



		background-size: 8px auto;



		background-position: right 10px center;



		border: 2px solid rgb(0,77,157);



		box-shadow: 4px 4px 1px 0px rgba(230,230,230,1);



		margin: 40px auto 0 auto;



		max-width: 320px;



		min-height: 60px;



		transition: all 0.5s ease;



		width: 100%;



	}



	.aen-button > button:hover {



		color: rgb(0,77,157);



		background-position: right 0px center;



		box-shadow: 0px 0px 0px 0px rgba(230,230,230,1);



	}







.aen-button-b {



	/*text-align: center;*/



}



	.aen-button-b > a {



		display: block;



		align-items: center;



		background-color: rgba(0,77,157,1);



		padding: 5px 28px 5px 12px;



		background-image: url(../images/arrow-border-8x12-white-next-.png);



		background-repeat: no-repeat;



		background-size: 8px auto;



		background-position: right 10px center;



		border: 2px solid rgb(0,77,157);



		color: rgb(255,255,255);



		margin: 40px auto 0 auto;



		max-width: 320px;



		min-height: 60px;



		position: relative;



		transition: all 0.5s ease;



		width: 100%;



	}



	.aen-button-b > a:hover {



		background-position: right 0px center;



		box-shadow: none;



	}



		.aen-button-b > a > span {



			position: absolute;



			top: 50%;



			left: 50%;



			-webkit-transform: translate(-50%, -50%);



			transform: translate(-50%, -50%);



		}







.aen-button-c {



	/*text-align: center;*/



}



	.aen-button-c > a {



		display: block;



		align-items: center;



		background-color: rgba(241,90,36,1);



		padding: 5px 28px 5px 12px;



		background-image: url(../images/arrow-border-8x12-white-next-.png);



		background-repeat: no-repeat;



		background-size: 8px auto;



		background-position: right 10px center;



		/*border: 2px solid rgb(241,90,36,1);*/



		color: rgb(255,255,255);



		margin: 40px auto 0 auto;



		max-width: 320px;



		min-height: 60px;



		position: relative;



		transition: all 0.5s ease;



		width: 100%;



	}



	.aen-button-c > a:hover {



		background-position: right 0px center;



		box-shadow: none;



	}



		.aen-button-c > a > span {



			position: absolute;



			top: 50%;



			left: 50%;



			-webkit-transform: translate(-50%, -50%);



			transform: translate(-50%, -50%);



			text-align: center;



			padding: 0 20px;



			width: 100%;



		}







.aen-form-reset {



	/*text-align: center;*/



}



	.aen-form-reset > input[type="reset"] {



		display: block;



		align-items: center;



		background-color: rgba(255,255,255,1);



		padding: 5px 25px 5px 12px;



		background-image: url(../images/arrow-border-8x12-black-next-.png);



		background-repeat: no-repeat;



		background-size: 8px auto;



		background-position: right 10px center;



		border: 1px solid rgb(153,153,153);



		color: rgb(51,51,51);



		margin: 15px auto 0 auto;



		max-width: 320px;



		min-height: 30px;



		position: relative;



		transition: all 0.5s ease;



		width: 100%;



	}



	.aen-form-reset > input[type="reset"]:hover {



		background-position: right 0px center;



		box-shadow: none;



	}



		/*.aen-form-reset > input[type="reset"] {



			position: absolute;



			top: 50%;



			left: 50%;



			-webkit-transform: translate(-50%, -50%);



			transform: translate(-50%, -50%);



			text-align: center;



			padding: 0 20px;



			width: 100%;



		}*/











.eat__shiteijoken {



	display: flex;



	font-size: 1.2rem;



	margin-bottom: 30px;



}



.eat__shiteijoken__left {



	flex-shrink: 0;



	padding: 7px 10px 7px 0;



}



.eat__shiteijoken__right {



	flex-grow: 1;



	background-color: #dbddff;



	border-radius: 10px;



	padding: 5px 10px;



}



.eat__shiteijoken__tags {



	display: flex;



	flex-wrap: wrap;



	margin-right: -5px;



	margin-top: -5px;



}



.eat__shiteijoken__tags span {



	display: block;



	background-color: #fff;



	border: 1px solid rgb(153,153,153);



	border-radius: 3px;



	margin-right: 5px;



	margin-top: 5px;



	padding: 0 5px;



}







.eat__dispnum {



	display: flex;



	align-items: center;



	margin-bottom: 20px;



}



.eat__dispnum__all {



	font-size: 2rem;



	margin-right: 5px;



}



.eat__dispnum__page {



	font-size: 1.4rem;



}







.eat__noarticle {



	padding: 20px;



	text-align: center;



	background-color: #f2f2f2;



}















/*



---



---------------------------------------------------------------------------*/



@media only screen and (max-width: 1023px) {



	



	.sub__sidemenu__wrapper {



		width: 40%;



		max-width: 300px;



	}











/*



---



---------------------------------------------------------------------------*/



	.greeting__main__thumb {



		margin-left: 20px;



	}



	



	



}











@media only screen and (max-width: 840px) {



	



	



	.greeting__main__thumb span {



		font-size: 1.2rem;



	}











/*



---



---------------------------------------------------------------------------*/



	.shisetsu__shisetsu__flex:before {



		width: 50%;



	}



	.shisetsu__shisetsu__thumb {



		max-width: 60px;



		align-self: flex-start;



	}



	.shisetsu__shisetsu__text p {



		font-size: 1.4rem;



	}











/*



---



---------------------------------------------------------------------------*/



	.movie__movie__flex {



		margin-top: -40px;



	}



	.movie__movie__flex > .movie__movie__item {



		width: 100%;



		padding-top: 40px;



	}



	.movie__movie__title {



		font-size: 1.6rem;



	}











/*



---



---------------------------------------------------------------------------*/



	.inquiery__main__text {



		 padding: 10px 20px 20px 30px;



	}











/*



---



---------------------------------------------------------------------------*/



	.sitemap__menu__ul > li {



		width: 100%;



		padding-left: 10px;



		padding-right: 10px;



	}



	.sitemap__menu__ul > li:nth-of-type(odd) {



		border-right-width: 0;



	}











/*



---



---------------------------------------------------------------------------*/



	.news__article__thumb span {



		transform: scale(0.7);



		transform-origin: right bottom;



		padding-left: 5px;



		padding-right: 5px;



	}











/*



---



---------------------------------------------------------------------------*/



	.generalmeeting__past__linkbtn__flex > .generalmeeting__past__linkbtn__item {



		width: 100%;



	}











/*



---



---------------------------------------------------------------------------*/



	.memberlist__link__flex {



		flex-wrap: wrap;



	}



	.memberlist__link__name {



		width: 100%;



		padding-right: 38px;



		position: relative;



	}



	.memberlist__link__name:after {



		content: "";



		top: 0;



		bottom: 0;



		right: 0;



		width: 28px;



		position: absolute;



		background-color: #e9f0f9;



		background-image: url(../images/arrow-border-8x12-blue-next-.png);



		background-repeat: no-repeat;



		background-size: 8px auto;



		background-position: center;



	}



	.memberlist__link__contents:after {



		content: none;



	}











/*



---



---------------------------------------------------------------------------*/



	.regulations__main__flex {



		flex-wrap: wrap;



	}



	.regulations__main__left {



		width: 100%;



		padding-bottom: 10px;



	}











/*



---



---------------------------------------------------------------------------*/



	.ao__entry__flex {



		flex-wrap: wrap;



	}



	.ao__entry__left {



		padding-right: 0;



		width: 100%;



	}



	.ao__entry__right {



		max-width: none;



		width: 100%;



		text-align: center;



		padding-top: 40px;



	}



	



	



}











@media only screen and (max-width: 767px) {



	



	



	/*



	---mw wp form



	---------------------------------------------------------------------------*/



	.mw_wp_form table .nameField{



		display: block;



	}



	.mw_wp_form table td .nameField:first-child{



		margin: 0 0 5px;



	}











	/*



	---category.php



	---------------------------------------------------------------------------*/



	.pager select[name="sp_paginate_links"]{



		width: 150px;



	}



	



	



	/*



	---single.php



	---------------------------------------------------------------------------*/



	.singleArticle-catList{



		padding: 5px 10px 10px 10px;



	}



	.singleArticle-catList a{



		text-decoration: none;



		font-size: 1.2rem;



		padding: 5px;



	}



	



	



	/*



	---



	---------------------------------------------------------------------------*/



	.listlink_wrp a[href$=".pdf"]{



		padding-right: 40px;



	}



	.listlink_wrp a[href$=".pdf"]:after{



		width: 20px;



		height: 20px;



		-webkit-background-size: 20px auto;



		background-size: 20px auto;



	}











	/*



	---準備中



	---------------------------------------------------------------------------*/



	.under_construction{



		padding: 50px 0;



		font-size: 1.8rem;



	}



	



	



	/*



---



---------------------------------------------------------------------------*/



	h2{



		font-size: 2.4rem;



	}



	h3{



		font-size: 2rem;



	}



	h4{



		font-size: 1.9rem;



	}



	h5{



		font-size: 1.8rem;



	}



	h6{



		font-size: 1.7rem;



	}



	.contents_body p{



		margin-top: 20px;



	}







	.contents_body table{



		font-size: 1.4rem;



	}



	.contents_body th,



	.contents_body td{



		padding: 5px;



	}



	.contents_body table.table_smp_block,



	.contents_body table.table_smp_block tbody,



	.contents_body table.table_smp_block tr{



		display: block;



	}



	.contents_body table.table_smp_block{



		font-size: inherit;



		border-bottom: 1px solid #ddd;



	}



	.contents_body table.table_smp_block th,



	.contents_body table.table_smp_block td{



		display: block !important;



		width: auto !important;



		border-bottom-width: 0;



	}











/*



---



---------------------------------------------------------------------------*/



	.authForm__pass {



	    padding-left: 0;



	}



	.authForm__pass span {



	    position: relative;



	    display: block;



	    transform: none;



	}











/*



---



---------------------------------------------------------------------------*/



	.sub__header__wrapper h1 {



		padding: 20px;



		font-size: 2.4rem;



	}



	.sub__global__wrapper {



		display: none;



	}



	.header__middle {



		position: static;



		padding-top: 10px;



	}



	.contents_sub_flex {



		flex-wrap: wrap;



		justify-content: center;



	}



	.contents_body {



		width: 100%;



	}



	.sub__sidemenu__wrapper {



		width: 100%;



		max-width: none;



		padding: 40px 0 0;



	}











/*



---



---------------------------------------------------------------------------*/



	.generalmeeting__latest__flex {



		position: relative;



		padding: 20px 5px 20px 95px;



		flex-wrap: wrap;



	}



	.generalmeeting__latest__day {



		position: absolute;



		top: 20px;



		left: 5px;



		font-size: 1.4rem;



	}



	.generalmeeting__latest__place {



		padding: 10px 0 0;



	}



	.generalmeeting__latest__list td {



		padding: 10px;



	}



	.generalmeeting__latest__list td:nth-of-type(1) {



		width: 76px;



	}



	.generalmeeting__latest__list table {



		font-size: 1.2rem;



	}











/*



---



---------------------------------------------------------------------------*/



	.organization__shibu__shibu a {



		font-size: 1.1rem;



	}



	.organization__remodal__contents {



		padding: 20px;



	}











/*



---



---------------------------------------------------------------------------*/



	.delegate__main__block table {



		font-size: 1.2rem;



	}



	.delegate__main__block .col3 {



		width: 20px;



	}



	.delegate__main__block .col4 {



		width: 50px;



	}



	.delegate__main__block .col5 {



		width: 54px;



	}











/*



---



---------------------------------------------------------------------------*/



	.net__info__inner {



		padding: 20px;



	}



	.net__info__wrapper:before, .net__info__wrapper:after, .net__info__inner:before, .net__info__inner:after {



		border-width: 2px;



	}











	/*



	--- 飲食店/宿泊施設NAVI(2022.4.19設置)



	---------------------------------------------------------------------------*/



	.ae-navi-flame {



		flex-direction:column-reverse;



	}



		.ae-navi-flame .right {



			order: 2;



		}



			.ae-navi-flame .right .bg-image {



				display: block;



				margin: 0 auto;



			}



		.ae-navi-flame .left {



			min-width: auto;



			padding-right: 0;



			order: 1;



		}







		.pageslider__slick {



			max-width: auto;



			margin: 0 auto;



			padding: 0;



			z-index: -1;



		}







	.eat-list-flame h3 {



		font-size: 1.7rem;



	}



	.eat-list-flame .eat-ete {



		font-size: 1.2rem;



	}



		.eat-list-flame .left {



			max-width: 130px;



		}



			.eat-list-flame .left figure {



				min-width: 130px;



			}



				.eat-list-flame .left figure > img {



					/*width:200px;*/



					height:130px;



					object-fit:cover;



				}



	.eat-list-flame .eat-cat {



		display: none;



	}







}











@media only screen and (max-width: 500px) {











	/*



	--- 飲食店/宿泊施設NAVI(2022.4.19設置)



	---------------------------------------------------------------------------*/



	.aen_overview > h2 {



		font-size: 1.7rem;



		line-height: 1.7;



	}







	.ae-navi-flame {



		flex-direction:column-reverse;



	}



		.ae-navi-flame .right {



			order: 2;



		}



			.ae-navi-flame .right .bg-image {



				margin-top: 0;



			}



		.ae-navi-flame .left {



			min-width: auto;



			padding-right: 0;



			order: 1;



		}







	.ae-navi-flame-b {



		flex-direction: column;



	}



		.ae-navi-flame-b .left {



			max-width: auto;



			padding-right: 0;



		}



		.ae-navi-flame-b .right {



			padding-top: 50px;



			padding-left: 0;



		}







	.inner-flame {



		flex-direction: column;



	}











	/* single */



	.con-block > h3 {



		font-size: 1.6rem;



	}



		.con-block .block-sf {



			flex-direction: column;



		}



		.con-block .block-shop:nth-of-type(1) {



			flex-direction: column;



		}



			.con-block .block-shop:nth-of-type(1) div:nth-of-type(2) {



				background-color: transparent;



				padding: 0;



			}







			.con-block .block-message div:nth-of-type(3) {



				margin-left: 0;



			}







}







